# DataLoadStatus

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**conditions** | [**list[Condition]**](Condition.md) | Conditions consists of transition information on DataLoad&#39;s Phase | 
**duration** | **str** | Duration tell user how much time was spent to load the data | 
**phase** | **str** | Phase describes current phase of DataLoad | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


